@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tracking" "2.14"
+(define-package "tracking" "20250831.39"
   "Buffer modification tracking."
   ()
   :url "https://github.com/emacs-circe/circe/wiki/Tracking"
-  :commit "9d9f63fd7cf8812797eb0ef77d7969e7387a9eb9"
-  :revdesc "v2.14-0-g9d9f63fd7cf8"
+  :commit "254814886cb4fdeba0ab1a9df33f7cbcdc1900cf"
+  :revdesc "254814886cb4"
   :authors '(("Jorgen Schaefer" . "forcer@forcix.cx"))
   :maintainers '(("Jorgen Schaefer" . "forcer@forcix.cx")))
